coalib.bearlib.languages.definitions package — coala 0.11.0.rc1 documentation

# coalib.bearlib.languages.definitions package

## Submodules

## coalib.bearlib.languages.definitions.C module

## coalib.bearlib.languages.definitions.CPP module

## coalib.bearlib.languages.definitions.CSS module

## coalib.bearlib.languages.definitions.CSharp module

## coalib.bearlib.languages.definitions.Golang module

## coalib.bearlib.languages.definitions.Java module

## coalib.bearlib.languages.definitions.JavaScript module

## coalib.bearlib.languages.definitions.Python module

## coalib.bearlib.languages.definitions.Unknown module

## coalib.bearlib.languages.definitions.Vala module

## Module contents

This directory holds language definitions.

Language definitions hold expressions that help defining specific syntax elements for a programming language.

Currently defined keys are:

> names extensions comment_delimiter multiline_comment_delimiters string_delimiters multiline_string_delimiters keywords special_chars